# Discrete constraints

## Discrete point constraints

::: phydrax.constraints.PointSetConstraint
    options:
        members:
            - __init__
            - from_points
            - from_operator
            - loss

---

::: phydrax.constraints.DiscreteInteriorDataConstraint

---

::: phydrax.constraints.DiscreteTimeDataConstraint

## Discrete boundary / initial constraints

::: phydrax.constraints.DiscreteDirichletBoundaryConstraint

---

::: phydrax.constraints.DiscreteNeumannBoundaryConstraint

---

::: phydrax.constraints.DiscreteInitialConstraint

## Discrete ODE constraints

::: phydrax.constraints.DiscreteODEConstraint
